@@ -17,6 +17,9 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include "config.h"
+
+#include <config.h>
 #include "dvi-document.h"
 #include "ev-document-thumbnails.h"
 #include "ev-document-misc.h"
@@ -26,7 +29,6 @@
 #include "fonts.h"
 #include "cairo-device.h"
 
-#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
 GMutex *dvi_context_mutex = NULL;
@@ -73,10 +75,8 @@ static void dvi_document_do_color_special               (DviContext
 							 const char                *prefix,
 							 const char                *arg);
 
-G_DEFINE_TYPE_WITH_CODE 
-    (DviDocument, dvi_document, G_TYPE_OBJECT, 
-    {
-      G_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT, dvi_document_document_iface_init);    
+EV_BACKEND_REGISTER_WITH_CODE (DviDocument, dvi_document,
+     {
       G_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT_THUMBNAILS, dvi_document_document_thumbnails_iface_init);
       G_IMPLEMENT_INTERFACE (EV_TYPE_FILE_EXPORTER, dvi_document_file_exporter_iface_init);
      });
@@ -363,7 +363,7 @@ dvi_document_file_exporter_begin (EvFileExporter        *exporter,
 	
 	if (dvi_document->exporter_filename)
 		g_free (dvi_document->exporter_filename);	
-	dvi_document->exporter_filename = g_strdup(fc->filename);
+	dvi_document->exporter_filename = g_strdup (fc->filename);
 	
 	if (dvi_document->exporter_opts) {
 		g_string_free (dvi_document->exporter_opts, TRUE);
@@ -377,7 +377,7 @@ dvi_document_file_exporter_do_page (EvFileExporter  *exporter,
 {
        DviDocument *dvi_document = DVI_DOCUMENT(exporter);
 
-       g_string_append_printf(dvi_document->exporter_opts, "%d,", (rc->page)+1);
+       g_string_append_printf (dvi_document->exporter_opts, "%d,", (rc->page) + 1);
 }
 
 static void
@@ -390,7 +390,7 @@ dvi_document_file_exporter_end (EvFileExporter *exporter)
 	
 	DviDocument *dvi_document = DVI_DOCUMENT(exporter);
 	
-	command_line = g_strdup_printf ("dvipdfm %s -o %s %s", /* dvipdfm -s 1,2,.., -o exporter_filename dvi_filename */
+	command_line = g_strdup_printf ("dvipdfm %s -o %s \"%s\"", /* dvipdfm -s 1,2,.., -o exporter_filename dvi_filename */
 					dvi_document->exporter_opts->str,
 					dvi_document->exporter_filename,
 					dvi_document->context->filename);
@@ -401,7 +401,7 @@ dvi_document_file_exporter_end (EvFileExporter *exporter)
 					     &exit_stat,
 					     &err);
 
-	g_free(command_line);
+	g_free (command_line);
 
 	if (success == FALSE) {
 		g_warning ("Error: %s", err->message);
@@ -410,7 +410,7 @@ dvi_document_file_exporter_end (EvFileExporter *exporter)
 	}
 
 	if (err)
-		g_error_free(err);
+		g_error_free (err);
 }
 
 static EvFileExporterCapabilities
