@@ -28,6 +28,8 @@
 #include <gdk/gdkx.h>
 #include <string.h>
 #include <stdlib.h>
+#include <sys/types.h>
+#include <signal.h>
 #include <sys/wait.h>
 #include <errno.h>
 
