@@ -23,9 +23,6 @@
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gtk/gtk.h>
-#ifdef WITH_GNOME_PRINT
-#include <libgnomeprintui/gnome-print-dialog.h>
-#endif
 
 G_BEGIN_DECLS
 
@@ -40,16 +37,13 @@ void 			ev_gui_menu_position_tree_selection (GtkMenu   *menu,
 							     gboolean  *push_in,
 							     gpointer   user_data);
 
-#ifdef WITH_GNOME_PRINT
-GnomePrintConfig* 	load_print_config_from_file (void);
-void       		save_print_config_to_file (GnomePrintConfig *config);
-gboolean		using_postscript_printer (GnomePrintConfig *config);
-gboolean		using_pdf_printer (GnomePrintConfig *config);
-#endif
 gint 			get_num_monitors (GtkWindow * window);
 
 gdouble 		get_screen_dpi (GtkWindow * window);
 
+void           		file_chooser_dialog_add_writable_pixbuf_formats (GtkFileChooser *chooser);
+GdkPixbufFormat* 	get_gdk_pixbuf_format_by_extension (gchar *uri);
+
 G_END_DECLS
 
 #endif /* __EV_VIEW_H__ */
