@@ -22,6 +22,7 @@
 
 #include <gtk/gtkwidget.h>
 #include <gtk/gtklayout.h>
+#include <gtk/gtkscrolledwindow.h>
 
 #include "ev-document.h"
 #include "ev-link.h"
@@ -72,7 +73,6 @@ void		ev_view_set_document	  (EvView         *view,
 			   		   EvDocument     *document);
 void 		ev_view_set_loading       (EvView 	  *view,
 				           gboolean        loading);
-
 /* Clipboard */
 void		ev_view_copy		  (EvView         *view);
 void		ev_view_select_all	  (EvView         *view);
@@ -108,11 +108,6 @@ void		ev_view_set_zoom	  (EvView         *view,
 					   double          factor,
 					   gboolean        relative);
 double		ev_view_get_zoom	  (EvView         *view);
-void		ev_view_set_zoom_for_size (EvView         *view,
-					   int             width,
-		    			   int             height,
-					   int             vsb_width,
-					   int             hsb_height);
 void            ev_view_set_screen_dpi    (EvView         *view,
 					   gdouble         dpi);
 void		ev_view_rotate_left       (EvView         *view);
@@ -122,11 +117,14 @@ void            ev_view_set_rotation      (EvView         *view,
 int             ev_view_get_rotation      (EvView         *view);
 
 /* Find */
-gboolean        ev_view_can_find_next     (EvView         *view);
-void            ev_view_find_next         (EvView         *view);
-gboolean        ev_view_can_find_previous (EvView         *view);
-void            ev_view_find_previous     (EvView         *view);
-void            ev_view_search_changed    (EvView         *view);
+gboolean        ev_view_can_find_next        (EvView         *view);
+void            ev_view_find_next            (EvView         *view);
+gboolean        ev_view_can_find_previous    (EvView         *view);
+void            ev_view_find_previous        (EvView         *view);
+void            ev_view_search_changed       (EvView         *view);
+void     	ev_view_set_highlight_search (EvView         *view,
+					      gboolean        value);
+void            ev_view_find_cancel          (EvView         *view);
 
 /* Status */
 const char     *ev_view_get_status        (EvView         *view);
@@ -146,6 +144,11 @@ gboolean       ev_view_next_page	  (EvView         *view);
 gboolean       ev_view_previous_page	  (EvView         *view);
 gchar*         ev_view_page_label_from_dest (EvView *view, EvLinkDest *dest);
 
+void           ev_view_update_view_size (EvView *view, GtkScrolledWindow *scrolled_window);
+
+void	       ev_view_autoscroll_start   (EvView *view);
+void           ev_view_autoscroll_stop    (EvView *view);
+
 G_END_DECLS
 
 #endif /* __EV_VIEW_H__ */
