@@ -17,16 +17,21 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
 #include "ev-window-title.h"
-#include "ev-document-factory.h"
+#include "ev-backends-manager.h"
 
+#include <gio/gio.h>
 #include <glib/gi18n.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
+
+/* Known backends (for bad extensions fix) */
+#define EV_BACKEND_PS  "psdocument"
+#define EV_BACKEND_PDF "pdfdocument"
 
 typedef struct
 {
-	EvBackend backend;
-	const char *ext;
+	const gchar *backend;
+	const gchar *ext;
 } BadExtensionEntry;
 
 struct _EvWindowTitle
@@ -60,12 +65,12 @@ ev_window_title_new (EvWindow *window)
 static char *
 get_filename_from_uri (const char *uri)
 {
+	GFile *file;
 	char *filename;
-	char *display_name;
-
-	display_name = gnome_vfs_format_uri_for_display (uri);
-	filename = g_path_get_basename (display_name);
-	g_free (display_name);
+	
+	file = g_file_new_for_uri (uri);
+	filename = g_file_get_basename (file);
+	g_object_unref (file);
 
 	return filename;
 }
@@ -74,12 +79,13 @@ get_filename_from_uri (const char *uri)
    Let's show the filename in this case */
 static void
 ev_window_title_sanitize_extension (EvWindowTitle *window_title, char **title) {
-	EvBackend backend;
+	const gchar *backend;
 	int i;
 
-	backend = ev_document_factory_get_backend (window_title->document);
+	backend = ev_backends_manager_get_document_module_name (window_title->document);
+
 	for (i = 0; i < G_N_ELEMENTS (bad_extensions); i++) {
-		if (bad_extensions[i].backend == backend &&
+		if (g_ascii_strcasecmp (bad_extensions[i].backend, backend) == 0 && 
 		    g_str_has_suffix (*title, bad_extensions[i].ext)) {
 			char *new_title;
 			char *filename = get_filename_from_uri (window_title->uri);
