@@ -25,23 +25,43 @@
 
 #include <glib-object.h>
 #include <gtk/gtkwindow.h>
+#include <gtk/gtkscrolledwindow.h>
 
 #include "ev-link.h"
 #include "ev-page-cache.h"
 
 G_BEGIN_DECLS
 
+typedef enum {
+	EV_WINDOW_MODE_NORMAL,
+	EV_WINDOW_MODE_FULLSCREEN,
+	EV_WINDOW_MODE_PRESENTATION,
+	EV_WINDOW_MODE_PREVIEW
+} EvWindowRunMode;
+
+typedef struct {
+	gint start;
+	gint end;
+} EvPrintRange;
+
+typedef enum {
+	EV_PRINT_PAGE_SET_ALL,
+	EV_PRINT_PAGE_SET_EVEN,
+	EV_PRINT_PAGE_SET_ODD
+} EvPrintPageSet;
+
 typedef struct _EvWindow EvWindow;
 typedef struct _EvWindowClass EvWindowClass;
 typedef struct _EvWindowPrivate EvWindowPrivate;
 
 #define EV_TYPE_WINDOW			(ev_window_get_type())
 #define EV_WINDOW(object)		(G_TYPE_CHECK_INSTANCE_CAST((object), EV_TYPE_WINDOW, EvWindow))
-#define EV_WINDOW_CLASS(klass)		(G_TYPE_CHACK_CLASS_CAST((klass), EV_TYPE_WINDOW, EvWindowClass))
+#define EV_WINDOW_CLASS(klass)		(G_TYPE_CHECK_CLASS_CAST((klass), EV_TYPE_WINDOW, EvWindowClass))
 #define EV_IS_WINDOW(object)		(G_TYPE_CHECK_INSTANCE_TYPE((object), EV_TYPE_WINDOW))
 #define EV_IS_WINDOW_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE((klass), EV_TYPE_WINDOW))
 #define EV_WINDOW_GET_CLASS(object)	(G_TYPE_INSTANCE_GET_CLASS((object), EV_TYPE_WINDOW, EvWindowClass))
 
+
 struct _EvWindow {
 	GtkWindow		base_instance;
 	EvWindowPrivate		*priv;
@@ -56,16 +76,16 @@ GtkWidget      *ev_window_new             (void);
 const char     *ev_window_get_uri         (EvWindow       *ev_window);
 void		ev_window_open_uri	  (EvWindow       *ev_window,
 					   const char     *uri,
-					   EvLinkDest     *dest);
-void            ev_window_goto_dest       (EvWindow       *ev_window,
-					   EvLinkDest     *dest);
+					   EvLinkDest     *dest,
+					   EvWindowRunMode mode,
+					   const gchar    *search_string,
+					   gboolean        unlink_temp_file,
+					   const gchar    *print_settings);
 gboolean	ev_window_is_empty	  (const EvWindow *ev_window);
-#ifdef WITH_GNOME_PRINT
 void		ev_window_print_range     (EvWindow       *ev_window,
 					   int             first_page,
 					   int		   last_page);
-#endif
+
 G_END_DECLS
 
 #endif /* !EV_WINDOW_H */
-
