@@ -16,16 +16,15 @@
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
-#include <libgnomevfs/gnome-vfs-mime-utils.h>
-#include <libgnomevfs/gnome-vfs-uri.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
-#include <libgnomevfs/gnome-vfs-init.h>
-#include <libgnomevfs/gnome-vfs-ops.h>
+#include <config.h>
 
 #include <ev-document.h>
 #include <ev-document-thumbnails.h>
 #include <ev-async-renderer.h>
 #include <ev-document-factory.h>
+#include <ev-backends-manager.h>
+
+#include <gio/gio.h>
 
 #include <stdlib.h>
 #include <string.h>
@@ -136,6 +135,7 @@ main (int argc, char *argv[])
 	const char *output;
 	int         size;
 	char       *uri;
+	GFile      *file;
 
 	if (argc <= 2 || argc > 5 || strcmp (argv[1], "-h") == 0 ||
 	    strcmp (argv[1], "--help") == 0) {
@@ -158,21 +158,29 @@ main (int argc, char *argv[])
 		return -1;
 	}
 
+	g_type_init ();
+
 	if (!g_thread_supported ())
 		g_thread_init (NULL);
-	
-	gnome_vfs_init ();
 
-	uri = gnome_vfs_make_uri_from_shell_arg (input);
+	ev_backends_manager_init ();
+
+	file = g_file_new_for_commandline_arg (input);
+	uri = g_file_get_uri (file);
 	document = evince_thumbnailer_get_document (uri);
+
+	g_object_unref (file);
 	g_free (uri);
 
-	if (!document)
+	if (!document) {
+		ev_backends_manager_shutdown ();
 		return -2;
+	}
 
 	if (!EV_IS_DOCUMENT_THUMBNAILS (document)) {
 		g_object_unref (document);
-		return FALSE;
+		ev_backends_manager_shutdown ();
+		return -2;
 	}
 
 	if (EV_IS_ASYNC_RENDERER (document)) {
@@ -190,16 +198,19 @@ main (int argc, char *argv[])
 		gtk_main ();
 
 		g_object_unref (document);
+		ev_backends_manager_shutdown ();
 
 		return data.success ? 0 : -2;
 	}
 
 	if (!evince_thumbnail_pngenc_get (document, output, size)) {
 		g_object_unref (document);
+		ev_backends_manager_shutdown ();
 		return -2;
 	}
 
 	g_object_unref (document);
+	ev_backends_manager_shutdown ();
 
 	return 0;
 }
